@@ -386,11 +386,12 @@ thumb_loader_start__step2 (ThumbLoader *tl)
 							     tl->priv->file->path,
 							     tl->priv->file->mtime);
 
-		if ((cache_path == NULL) &&
-		    ((time (NULL) - tl->priv->file->mtime) > (time_t) 5) &&
-		    gnome_thumbnail_factory_has_valid_failed_thumbnail (tl->priv->thumb_factory,
-									tl->priv->file->path,
-									tl->priv->file->mtime)) {
+		if ((cache_path == NULL)  
+		    && gnome_thumbnail_factory_has_valid_failed_thumbnail (tl->priv->thumb_factory,
+									   tl->priv->file->path,
+									   tl->priv->file->mtime)
+		    && ((time (NULL) - tl->priv->file->mtime) > (time_t) 5)) 
+		{
 			/* Use the existing "failed" thumbnail, if it is over
 			   5 seconds old. Otherwise, try to thumbnail it again. 
 			   The minimum age requirement addresses bug 432759, 
@@ -532,9 +533,10 @@ thumb_loader_done_cb (ImageLoader *il,
 		 * scaled if necessary. */
 
 		/* Check whether to scale. */
-		modified = scale_keepping_ratio (&width, &height,
+		modified = scale_keeping_ratio (&width, &height,
 						 priv->cache_max_w,
-						 priv->cache_max_h);
+						 priv->cache_max_h,
+						 FALSE);
 		if (modified) {
 			g_object_unref (priv->pixbuf);
 			priv->pixbuf = gdk_pixbuf_scale_simple (pixbuf,
@@ -544,7 +546,7 @@ thumb_loader_done_cb (ImageLoader *il,
 		}
 
 		/* Save the thumbnail if necessary. */
-		if (! priv->from_cache && priv->save_thumbnails)
+		if (priv->save_thumbnails && ! priv->from_cache)
 			thumb_loader_save_to_cache (tl);
 
 		/* Scale if the user wants a different size. */
@@ -564,7 +566,7 @@ thumb_loader_done_cb (ImageLoader *il,
 		}
 	} 
 	else {
-		modified = scale_keepping_ratio (&width, &height, priv->max_w, priv->max_h);
+		modified = scale_keeping_ratio (&width, &height, priv->max_w, priv->max_h, FALSE);
 		if (modified) {
 			g_object_unref (priv->pixbuf);
 			priv->pixbuf = gdk_pixbuf_scale_simple (pixbuf,
@@ -603,7 +605,6 @@ thumb_loader_error_cb (ImageLoader *il,
 	/* Try from the original if cache load attempt failed. */
 	
 	priv->from_cache = FALSE;
-	g_warning ("Thumbnail image in cache failed to load, trying to recreate.");
 
 	image_loader_set_file (priv->il, priv->file);
 	image_loader_start (priv->il);
