@@ -56,7 +56,7 @@
 #define DEF_PAGE_HEIGHT     400
 #define DEF_THUMB_SIZE      128
 
-static int           sort_method_to_idx[] = { -1, 0, 1, 2, 3, 4, 5 };
+static int           sort_method_to_idx[] = { -1, 0, 1, 2, 3, 4, 5, 6 };
 static GthSortMethod idx_to_sort_method[] = { GTH_SORT_METHOD_BY_NAME,
 					      GTH_SORT_METHOD_BY_PATH,
 					      GTH_SORT_METHOD_BY_SIZE,
@@ -152,7 +152,7 @@ export (GtkWidget  *widget,
 
 	gtk_widget_hide (data->dialog);
 
-	catalog_png_exporter_set_directory (exporter, dir);
+	catalog_png_exporter_set_location (exporter, dir);
 	g_free (dir);
 
 	file_type = eel_gconf_get_string (PREF_EXP_FILE_TYPE, DEF_FILE_TYPE);
@@ -340,7 +340,7 @@ dlg_exporter (GthBrowser *browser)
 
 	data->browser = browser;
 
-	list = gth_window_get_file_list_selection (GTH_WINDOW (browser));
+	list = gth_window_get_file_list_selection_as_fd (GTH_WINDOW (browser));
 	if (list == NULL) {
 		g_warning ("No file selected.");
 		g_free (data);
@@ -348,8 +348,7 @@ dlg_exporter (GthBrowser *browser)
 	}
 
 	data->exporter = catalog_png_exporter_new (list);
-	g_list_foreach (list, (GFunc) g_free, NULL);
-	g_list_free (list);
+	file_data_list_free (list);
 
 	data->gui = glade_xml_new (GTHUMB_GLADEDIR "/" GLADE_EXPORTER_FILE, NULL, NULL);
         if (!data->gui) {
@@ -426,7 +425,8 @@ dlg_exporter (GthBrowser *browser)
 
 	/**/
 
-	gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (data->dest_filechooserbutton), gth_browser_get_current_directory (browser));
+	gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (data->dest_filechooserbutton),
+						 gth_browser_get_current_directory (browser));
 
 	template = eel_gconf_get_string (PREF_EXP_NAME_TEMPLATE, DEF_NAME_TEMPLATE);
 	if (template != NULL)
@@ -470,7 +470,6 @@ dlg_exporter (GthBrowser *browser)
 }
 
 
-
 /* -- Exporter Preferences -- */
 
 typedef struct {
@@ -1331,6 +1330,7 @@ dlg_png_exporter_pref (DialogData *ddata)
 	data->gui = glade_xml_new (GTHUMB_GLADEDIR "/" GLADE_EXPORTER_FILE, NULL, NULL);
         if (!data->gui) {
                 g_warning ("Could not find " GLADE_EXPORTER_FILE "\n");
+		g_free (data);
                 return;
         }
 
