@@ -47,7 +47,7 @@
 #include "gth-utils.h"
 #include "glib-utils.h"
 
-static int           sort_method_to_idx[] = { -1, 0, 1, 2, 3, 4, 5 };
+static int           sort_method_to_idx[] = { -1, 0, 1, 2, 3, 4, 5, 6 };
 static GthSortMethod idx_to_sort_method[] = { GTH_SORT_METHOD_BY_NAME,
 					      GTH_SORT_METHOD_BY_PATH,
 					      GTH_SORT_METHOD_BY_SIZE,
@@ -386,19 +386,19 @@ get_default_theme (void)
 void
 dlg_web_exporter (GthBrowser *browser)
 {
-	DialogData   *data;
-	GtkWidget    *btn_cancel;
-	GtkWidget    *btn_help;
-	GList        *list;
-	char         *svalue;
-	gboolean      reorderable;
-	int           idx;
+	DialogData *data;
+	GtkWidget  *btn_cancel;
+	GtkWidget  *btn_help;
+	GList      *list;
+	char       *svalue;
+	gboolean    reorderable;
+	int         idx;
 
 	data = g_new0 (DialogData, 1);
 
 	data->browser = browser;
 
-	list = gth_window_get_file_list_selection (GTH_WINDOW (browser));
+	list = gth_window_get_file_list_selection_as_fd (GTH_WINDOW (browser));
 	if (list == NULL) {
 		g_warning ("No file selected.");
 		g_free (data);
@@ -408,8 +408,7 @@ dlg_web_exporter (GthBrowser *browser)
 	reorderable = gth_file_view_get_reorderable (gth_browser_get_file_view (browser));
 
 	data->exporter = catalog_web_exporter_new (GTH_WINDOW (browser), list);
-	g_list_foreach (list, (GFunc) g_free, NULL);
-	g_list_free (list);
+	file_data_list_free (list);
 
 	data->gui = glade_xml_new (GTHUMB_GLADEDIR "/" GLADE_EXPORTER_FILE, NULL, NULL);
         if (!data->gui) {
@@ -524,7 +523,7 @@ dlg_web_exporter (GthBrowser *browser)
 	svalue = eel_gconf_get_path (PREF_WEB_ALBUM_DESTINATION, NULL);
 	if (svalue == NULL)
 		svalue = g_strdup (g_get_home_dir ());
-	gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (data->wa_destination_filechooserbutton), svalue);
+	gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (data->wa_destination_filechooserbutton), svalue);
 	g_free (svalue);
 
 	/* Signals. */
@@ -593,7 +592,7 @@ dlg_web_exporter (GthBrowser *browser)
 	/* Run dialog. */
 
 	gtk_window_set_transient_for (GTK_WINDOW (data->dialog), GTK_WINDOW (browser));
-	gtk_window_set_modal (GTK_WINDOW (data->dialog), FALSE);
+	gtk_window_set_modal (GTK_WINDOW (data->dialog), TRUE);
 	gtk_widget_show_all (data->dialog);
 }
 
@@ -766,11 +765,10 @@ ensure_local_theme_dir_exists (void)
 {
 	char *theme_dir;
 
-	theme_dir = g_build_path (G_DIR_SEPARATOR_S,
-				  get_home_uri (),
-				  ".gnome2",
-				  "gthumb/albumthemes",
-				  NULL);
+	theme_dir = build_uri (get_home_uri (),
+			       ".gnome2",
+			       "gthumb/albumthemes",
+			       NULL);
 
 	dir_make (theme_dir, 0700);
 
@@ -846,7 +844,8 @@ theme_dialog__install_theme_clicked (GtkWidget       *widget,
 {
 	GtkWidget *file_sel;
 
-	file_sel = gtk_file_chooser_dialog_new (_("Select Album Theme"), NULL,
+	file_sel = gtk_file_chooser_dialog_new (_("Select Album Theme"),
+						GTK_WINDOW (tdata->dialog),
 						GTK_FILE_CHOOSER_ACTION_OPEN,
 						GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 						GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
@@ -854,19 +853,16 @@ theme_dialog__install_theme_clicked (GtkWidget       *widget,
 
 	/* Permit VFS URIs */
 	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (file_sel), FALSE);
+	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (file_sel), g_get_home_dir ());
+	gtk_dialog_set_default_response (GTK_DIALOG (file_sel), GTK_RESPONSE_ACCEPT);
 
-	gtk_window_set_modal (GTK_WINDOW (file_sel), TRUE);
 	g_object_set_data (G_OBJECT (file_sel), "theme_dialog_data", tdata);
 
-	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (file_sel), g_get_home_dir ());
-
-	g_signal_connect (GTK_DIALOG (file_sel),
+	g_signal_connect (G_OBJECT (file_sel),
 			  "response",
 			  G_CALLBACK (install_theme_response_cb),
 			  NULL);
 
-	gtk_window_set_transient_for (GTK_WINDOW (file_sel),
-				      GTK_WINDOW (tdata->dialog));
 	gtk_window_set_modal (GTK_WINDOW (file_sel), TRUE);
 	gtk_widget_show (file_sel);
 }
@@ -894,7 +890,7 @@ theme_dialog__go_to_folder_clicked (GtkWidget       *widget,
 /* called when an item of the catalog list is selected. */
 static void
 theme_dialog__sel_changed_cb (GtkTreeSelection *selection,
-			      gpointer p)
+			      gpointer          p)
 {
 	ThemeDialogData  *tdata = p;
 	gboolean          theme_selected;
@@ -930,25 +926,27 @@ theme_dialog__sel_changed_cb (GtkTreeSelection *selection,
 	}
 
 	if (path_is_dir (path)) {
-		char *filename = g_build_path (G_DIR_SEPARATOR_S,
-					       path,
-					       "preview.png",
-					       NULL);
-		if (path_is_file (filename)) {
-			GdkPixbuf *image = gth_pixbuf_new_from_uri (filename, NULL, 0, 0, NULL);
+		char      *filename;
+		GdkPixbuf *image = NULL;
+					       
+		filename = build_uri (path, "preview.png", NULL);
+		if (path_is_file (filename)
+		    && ((image = gdk_pixbuf_new_from_file (filename, NULL)) != NULL)) {
 			int        w = gdk_pixbuf_get_width (image);
 			int        h = gdk_pixbuf_get_height (image);
-			if (scale_keepping_ratio (&w, &h, MAX_PREVIEW_SIZE, MAX_PREVIEW_SIZE)) {
+			if (scale_keeping_ratio (&w, &h, MAX_PREVIEW_SIZE, MAX_PREVIEW_SIZE, FALSE)) {
 				GdkPixbuf *tmp = image;
 				image = gdk_pixbuf_scale_simple (tmp, w, h, GDK_INTERP_BILINEAR);
 				g_object_unref (tmp);
 			}
 			gtk_image_set_from_pixbuf (GTK_IMAGE (tdata->wat_preview_image), image);
-			g_object_unref (image);
-
-		} else
+		} 
+		else
 			gtk_image_set_from_stock (GTK_IMAGE (tdata->wat_preview_image), GTK_STOCK_MISSING_IMAGE, GTK_ICON_SIZE_BUTTON);
+
 		g_free (filename);
+		if (image != NULL)
+			g_object_unref (image);
 	}
 
 	g_free (utf8_name);
@@ -1064,13 +1062,11 @@ show_album_theme_cb (GtkWidget  *widget,
 	gtk_widget_grab_focus (tdata->wat_theme_treeview);
 
 	gtk_window_set_transient_for (GTK_WINDOW (tdata->dialog), GTK_WINDOW (data->dialog));
-	gtk_window_set_modal (GTK_WINDOW (tdata->dialog), FALSE);
+	gtk_window_set_modal (GTK_WINDOW (tdata->dialog), TRUE);
 	gtk_widget_show_all (tdata->dialog);
 }
 
 
-
-
 typedef struct {
 	DialogData         *data;
 	GthBrowser         *browser;
